Blancmange
==========

**Do you have enough Python in your Python?**


Blancmange is sweet dessert that once featured in Monty Python's Flying Circus
playing tennis.  At the time of writing, this term isn't featured anywhere in
the CPython core code or documentation.  This is sad since the notion of a
large, extra-terrestrial dessert trying to take over the world whilst playing
tennis is quite hilarious.  There are many more Python references that aren't
present in the documentation, source, or elsewhere, so let's fix that.

This tool can scan a prescribed directory of source and determine which terms
from Monty Python's Flying Circus feature and which don't.

Use it to Python-ise your Python.

In addition, it can output some fun statistics and answer some queries regarding
the 45 standard English-language Flying Circus episodes, including:

* Total words spoken (165,483)
* Who spoke the most out of the Pythons (Michael Palin, with 24% of the words)
* How often Spam was mentioned
*  ...


**Lacking rugged lumberjacks in your logging?**

**Not enough fun in your functions?**

Try Blancmanage today!


Todo
====

* Suggest where to add Python references and references which are needed.


